@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-04-08'; # DATE
-our $VERSION = '1.005'; # VERSION
+our $DATE = '2016-06-16'; # DATE
+our $VERSION = '1.006'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.005 of Bencher (from Perl distribution Bencher), released on 2016-04-08.
+This document describes version 1.006 of Bencher (from Perl distribution Bencher), released on 2016-06-16.
 
 =head1 SYNOPSIS
 
@@ -269,11 +269,25 @@ effect of showing nicer names (in the hash keys) for the argument value, e.g.:
 
 =item * include_participant_tags (array of str)
 
-Only include participants having all these tags.
+Only include participants having one of these tags. For example:
+
+ ['a', 'b']
+
+will include all participants having either C<a> or C<b> in their tags. To only
+include participants which have all of C<a> and C<b> in their tags, use:
+
+ ['a & b']
 
 =item * exclude_participant_tags (array of str)
 
-Exclude participants having any of these tags.
+Exclude participants having any of these tags. For example:
+
+ ['a', 'b']
+
+will exclude all participants having either C<a> or C<b> in their tags. To only
+exclude participants which have all of C<a> and C<b> in their tags, use:
+
+ ['a & b']
 
 =back
 
